==> aws-sdk-cpp-1.11.476-1-x86_64.pkg.tar.zst: usr/include/aws/security-ir/SecurityIREndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/security-ir/SecurityIR_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/security-ir/SecurityIREndpointRules.h>


namespace Aws
{
namespace SecurityIR
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using SecurityIRClientContextParameters = Aws::Endpoint::ClientContextParameters;

using SecurityIRClientConfiguration = Aws::Client::GenericClientConfiguration;
using SecurityIRBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the SecurityIR Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using SecurityIREndpointProviderBase =
    EndpointProviderBase<SecurityIRClientConfiguration, SecurityIRBuiltInParameters, SecurityIRClientContextParameters>;

using SecurityIRDefaultEpProviderBase =
    DefaultEndpointProvider<SecurityIRClientConfiguration, SecurityIRBuiltInParameters, SecurityIRClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_SECURITYIR_API SecurityIREndpointProvider : public SecurityIRDefaultEpProviderBase
{
public:
    using SecurityIRResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    SecurityIREndpointProvider()
      : SecurityIRDefaultEpProviderBase(Aws::SecurityIR::SecurityIREndpointRules::GetRulesBlob(), Aws::SecurityIR::SecurityIREndpointRules::RulesBlobSize)
    {}

    ~SecurityIREndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace SecurityIR
} // namespace Aws

==> aws-sdk-cpp-1.11.725-1-x86_64.pkg.tar.zst: usr/include/aws/security-ir/SecurityIREndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/security-ir/SecurityIREndpointRules.h>
#include <aws/security-ir/SecurityIR_EXPORTS.h>

namespace Aws {
namespace SecurityIR {
namespace Endpoint {
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::DefaultEndpointProvider;
using Aws::Endpoint::EndpointProviderBase;

using SecurityIRClientContextParameters = Aws::Endpoint::ClientContextParameters;

using SecurityIRClientConfiguration = Aws::Client::GenericClientConfiguration;
using SecurityIRBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the SecurityIR Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using SecurityIREndpointProviderBase =
    EndpointProviderBase<SecurityIRClientConfiguration, SecurityIRBuiltInParameters, SecurityIRClientContextParameters>;

using SecurityIRDefaultEpProviderBase =
    DefaultEndpointProvider<SecurityIRClientConfiguration, SecurityIRBuiltInParameters, SecurityIRClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_SECURITYIR_API SecurityIREndpointProvider : public SecurityIRDefaultEpProviderBase {
 public:
  using SecurityIRResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

  SecurityIREndpointProvider()
      : SecurityIRDefaultEpProviderBase(Aws::SecurityIR::SecurityIREndpointRules::GetRulesBlob(),
                                        Aws::SecurityIR::SecurityIREndpointRules::RulesBlobSize) {}

  ~SecurityIREndpointProvider() {}
};
}  // namespace Endpoint
}  // namespace SecurityIR
}  // namespace Aws
